"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const anchor_1 = require("@coral-xyz/anchor");
const web3_js_1 = require("@solana/web3.js");
const fs_1 = __importDefault(require("fs"));
const client_1 = require("../../src/client");
const constants_1 = require("../../src/constants");
const chai_1 = require("chai");
const mangoAccount_1 = require("../../src/accounts/mangoAccount");
//
// This script creates liquidation candidates
//
const GROUP_NUM = Number(process.env.GROUP_NUM || 200);
const CLUSTER = process.env.CLUSTER || 'mainnet-beta';
async function main() {
    const options = anchor_1.AnchorProvider.defaultOptions();
    options.commitment = 'processed';
    options.preflightCommitment = 'finalized';
    const connection = new web3_js_1.Connection(process.env.CLUSTER_URL, options);
    const admin = web3_js_1.Keypair.fromSecretKey(Buffer.from(JSON.parse(fs_1.default.readFileSync(process.env.PAYER_KEYPAIR, 'utf-8'))));
    const userWallet = new anchor_1.Wallet(admin);
    const userProvider = new anchor_1.AnchorProvider(connection, userWallet, options);
    const client = await client_1.MangoClient.connect(userProvider, CLUSTER, constants_1.MANGO_V4_ID[CLUSTER], {
        idsSource: 'get-program-accounts',
        prioritizationFee: 100,
        txConfirmationCommitment: 'confirmed',
    });
    // fetch group
    const group = await client.getGroupForCreator(admin.publicKey, GROUP_NUM);
    const accounts = await client.getMangoAccountsForOwner(group, admin.publicKey);
    const usdcBank = group.banksMapByName.get('USDC')[0];
    const solBank = group.banksMapByName.get('SOL')[0];
    // LIQEE1 executed up the the margin limit
    {
        const account = ensure(accounts.find((account) => account.name == 'LIQTEST, LIQEE1'));
        (0, chai_1.expect)(account.tokenConditionalSwapsActive.length).equal(0);
        (0, chai_1.expect)(Math.round(account.getTokenBalance(usdcBank).toNumber())).equal(1000 - 4715);
        (0, chai_1.expect)(account.getHealthRatioUi(group, mangoAccount_1.HealthType.init)).lessThan(1);
    }
    // LIQEE2 executed fully
    {
        const account = ensure(accounts.find((account) => account.name == 'LIQTEST, LIQEE2'));
        (0, chai_1.expect)(account.tokenConditionalSwapsActive.length).equal(0);
        (0, chai_1.expect)(Math.round(account.getTokenBalance(solBank).toNumber())).equal(991);
    }
    // LIQEE3 was closed due to expiry
    {
        const account = ensure(accounts.find((account) => account.name == 'LIQTEST, LIQEE3'));
        (0, chai_1.expect)(account.tokenConditionalSwapsActive.length).equal(0);
        (0, chai_1.expect)(Math.round(account.getTokenBalance(usdcBank).toNumber())).equal(1000000);
    }
    process.exit();
}
function ensure(value) {
    if (value == null) {
        throw new Error('Value was nullish');
    }
    return value;
}
main();
